@@ -18,7 +18,7 @@ import pims
 from . import _utils
 
 
-def imread(fname, nframes=1):
+def imread(fname, nframes=1, *, arraytype="numpy"):
     """
     Read image data into a Dask Array.
 
@@ -27,10 +27,12 @@ def imread(fname, nframes=1):
 
     Parameters
     ----------
-    fname : str
+    fname : str or pathlib.Path
         A glob like string that may match one or multiple filenames.
     nframes : int, optional
         Number of the frames to include in each chunk (default: 1).
+    arraytype : str, optional
+        Array type for dask chunks. Available options: "numpy", "cupy".
 
     Returns
     -------
@@ -38,12 +40,19 @@ def imread(fname, nframes=1):
         A Dask Array representing the contents of all image files.
     """
 
+    sfname = str(fname)
     if not isinstance(nframes, numbers.Integral):
         raise ValueError("`nframes` must be an integer.")
     if (nframes != -1) and not (nframes > 0):
         raise ValueError("`nframes` must be greater than zero.")
 
-    with pims.open(fname) as imgs:
+    if arraytype == "numpy":
+        arrayfunc = numpy.asanyarray
+    elif arraytype == "cupy":   # pragma: no cover
+        import cupy
+        arrayfunc = cupy.asanyarray
+
+    with pims.open(sfname) as imgs:
         shape = (len(imgs),) + imgs.frame_shape
         dtype = numpy.dtype(imgs.pixel_type)
 
@@ -63,19 +72,20 @@ def imread(fname, nframes=1):
             RuntimeWarning
         )
 
-    lower_iter, upper_iter = itertools.tee(itertools.chain(
-        range(0, shape[0], nframes),
-        [shape[0]]
-    ))
-    next(upper_iter)
-
-    a = []
-    for i, j in zip(lower_iter, upper_iter):
-        a.append(dask.array.from_delayed(
-            dask.delayed(_utils._read_frame)(fname, slice(i, j)),
-            (j - i,) + shape[1:],
-            dtype
-        ))
-    a = dask.array.concatenate(a)
+    a = dask.array.map_blocks(
+        _map_read_frame,
+        chunks=dask.array.core.normalize_chunks(
+            (nframes,) + shape[1:], shape),
+        fn=sfname,
+        arrayfunc=arrayfunc,
+        meta=arrayfunc([]).astype(dtype),  # meta overwrites `dtype` argument
+    )
 
     return a
+
+
+def _map_read_frame(block_info=None, **kwargs):
+
+    i, j = block_info[None]['array-location'][0]
+
+    return _utils._read_frame(i=slice(i, j), **kwargs)
