@@ -5,11 +5,12 @@
 from __future__ import absolute_import
 
 import numbers
+import pathlib
 
 import pytest
 
 import numpy as np
-from skimage.external import tifffile
+import tifffile
 
 import dask.array.utils as dau
 import dask_image.imread
@@ -36,17 +37,17 @@ def test_errs_imread(err_type, nframes):
     ]
 )
 @pytest.mark.parametrize(
-    "nframes, shape",
+    "nframes, shape, runtime_warning",
     [
-        (1, (1, 4, 3)),
-        (-1, (1, 4, 3)),
-        (3, (1, 4, 3)),
-        (1, (5, 4, 3)),
-        (2, (5, 4, 3)),
-        (1, (10, 5, 4, 3)),
-        (5, (10, 5, 4, 3)),
-        (10, (10, 5, 4, 3)),
-        (-1, (10, 5, 4, 3)),
+        (1, (1, 4, 3), None),
+        (-1, (1, 4, 3), None),
+        (3, (1, 4, 3), "`nframes` larger than"),
+        (1, (5, 4, 3), None),
+        (2, (5, 4, 3), "`nframes` does not nicely divide"),
+        (1, (10, 5, 4, 3), None),
+        (5, (10, 5, 4, 3), None),
+        (10, (10, 5, 4, 3), None),
+        (-1, (10, 5, 4, 3), None),
     ]
 )
 @pytest.mark.parametrize(
@@ -57,7 +58,14 @@ def test_errs_imread(err_type, nframes):
         np.float32,
     ]
 )
-def test_tiff_imread(tmpdir, seed, nframes, shape, dtype):
+@pytest.mark.parametrize(
+    "is_pathlib_Path",
+    [
+        True,
+        False,
+    ]
+)
+def test_tiff_imread(tmpdir, seed, nframes, shape, runtime_warning, dtype, is_pathlib_Path):
     np.random.seed(seed)
 
     dirpth = tmpdir.mkdir("test_imread")
@@ -72,9 +80,13 @@ def test_tiff_imread(tmpdir, seed, nframes, shape, dtype):
     fn = str(dirpth.join("test.tiff"))
     with tifffile.TiffWriter(fn) as fh:
         for i in range(len(a)):
-            fh.save(a[i])
+            fh.save(a[i], contiguous=True)
 
-    d = dask_image.imread.imread(fn, nframes=nframes)
+    with pytest.warns(None if runtime_warning is None
+                      else RuntimeWarning, match=runtime_warning):
+        if is_pathlib_Path:
+            fn = pathlib.Path(fn)
+        d = dask_image.imread.imread(fn, nframes=nframes)
 
     if nframes == -1:
         nframes = shape[0]
